@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1996, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1996, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -44,6 +44,7 @@ import java.io.StreamCorruptedException;
 
 import java.lang.reflect.Modifier;
 
+import java.net.MalformedURLException;
 import java.net.URL;
 
 import java.util.Enumeration;
@@ -75,9 +76,9 @@ public class Beans {
      * @param     beanName    the name of the bean within the class-loader.
      *                        For example "sun.beanbox.foobah"
      *
-     * @exception ClassNotFoundException if the class of a serialized
+     * @throws ClassNotFoundException if the class of a serialized
      *              object could not be found.
-     * @exception IOException if an I/O error occurs.
+     * @throws IOException if an I/O error occurs.
      */
 
     public static Object instantiate(ClassLoader cls, String beanName) throws IOException, ClassNotFoundException {
@@ -97,12 +98,14 @@ public class Beans {
      *                        For example "sun.beanbox.foobah"
      * @param     beanContext The BeanContext in which to nest the new bean
      *
-     * @exception ClassNotFoundException if the class of a serialized
+     * @throws ClassNotFoundException if the class of a serialized
      *              object could not be found.
-     * @exception IOException if an I/O error occurs.
+     * @throws IOException if an I/O error occurs.
      * @since 1.2
+     * @deprecated this method will be removed when java.beans.beancontext is removed
      */
-    @SuppressWarnings("deprecation")
+    @Deprecated(since = "23", forRemoval = true)
+    @SuppressWarnings({"deprecation", "removal"})
     public static Object instantiate(ClassLoader cls, String beanName,
                                      BeanContext beanContext)
             throws IOException, ClassNotFoundException {
@@ -135,7 +138,7 @@ public class Beans {
      * a classname the applet's "init" method is called.  (If the bean was
      * deserialized this step is skipped.)
      * <p>
-     * Note that for beans which are applets, it is the caller's responsiblity
+     * Note that for beans which are applets, it is the caller's responsibility
      * to call "start" on the applet.  For correct behaviour, this should be done
      * after the applet has been added into a visible AWT container.
      * <p>
@@ -156,9 +159,9 @@ public class Beans {
      * @param     beanContext The BeanContext in which to nest the new bean
      * @param     initializer The AppletInitializer for the new bean
      *
-     * @exception ClassNotFoundException if the class of a serialized
+     * @throws ClassNotFoundException if the class of a serialized
      *              object could not be found.
-     * @exception IOException if an I/O error occurs.
+     * @throws IOException if an I/O error occurs.
      * @since 1.2
      *
      * @deprecated It is recommended to use
@@ -167,7 +170,8 @@ public class Beans {
      * <a href="../../java/applet/package-summary.html"> java.applet package
      * documentation</a> for further information.
      */
-    @Deprecated(since = "9")
+    @Deprecated(since = "9", forRemoval = true)
+    @SuppressWarnings("removal")
     public static Object instantiate(ClassLoader cls, String beanName,
                                      BeanContext beanContext,
                                      AppletInitializer initializer)
@@ -200,7 +204,7 @@ public class Beans {
         else
             ins =  cls.getResourceAsStream(serName);
         if (ins != null) {
-            try {
+            try (ins) {
                 if (cls == null) {
                     oins = new ObjectInputStream(ins);
                 } else {
@@ -210,13 +214,9 @@ public class Beans {
                 serialized = true;
                 oins.close();
             } catch (IOException ex) {
-                ins.close();
                 // Drop through and try opening the class.  But remember
                 // the exception in case we can't find the class either.
                 serex = ex;
-            } catch (ClassNotFoundException ex) {
-                ins.close();
-                throw ex;
             }
         }
 
@@ -270,7 +270,7 @@ public class Beans {
                     // massaging the URL.
 
                     // First find the "resource name" corresponding to the bean
-                    // itself.  So a serialzied bean "a.b.c" would imply a
+                    // itself.  So a serialized bean "a.b.c" would imply a
                     // resource name of "a/b/c.ser" and a classname of "x.y"
                     // would imply a resource name of "x/y.class".
 
@@ -288,7 +288,7 @@ public class Beans {
                     URL codeBase  = null;
                     URL docBase   = null;
 
-                    // Now get the URL correponding to the resource name.
+                    // Now get the URL corresponding to the resource name.
                     if (cls == null) {
                         objectUrl = ClassLoader.getSystemResource(resourceName);
                     } else
@@ -307,13 +307,13 @@ public class Beans {
 
                         if (s.endsWith(resourceName)) {
                             int ix   = s.length() - resourceName.length();
-                            codeBase = new URL(s.substring(0,ix));
+                            codeBase = newURL(s.substring(0,ix));
                             docBase  = codeBase;
 
                             ix = s.lastIndexOf('/');
 
                             if (ix >= 0) {
-                                docBase = new URL(s.substring(0,ix+1));
+                                docBase = newURL(s.substring(0,ix+1));
                             }
                         }
                     }
@@ -354,11 +354,17 @@ public class Beans {
         return result;
     }
 
-    @SuppressWarnings("unchecked")
+    @Deprecated(since = "23", forRemoval = true)
+    @SuppressWarnings({ "unchecked", "removal" })
     private static void unsafeBeanContextAdd(BeanContext beanContext, Object res) {
         beanContext.add(res);
     }
 
+    @SuppressWarnings("deprecation")
+    private static URL newURL(String spec) throws MalformedURLException {
+        return new URL(spec);
+    }
+
     /**
      * From a given bean, obtain an object representing a specified
      * type view of that source object.
@@ -435,7 +441,7 @@ public class Beans {
      * method is called. This could result in a SecurityException.
      *
      * @param isDesignTime  True if we're in an application builder tool.
-     * @exception  SecurityException  if a security manager exists and its
+     * @throws  SecurityException  if a security manager exists and its
      *             {@code checkPropertiesAccess} method doesn't allow setting
      *              of system properties.
      * @see SecurityManager#checkPropertiesAccess
@@ -443,6 +449,7 @@ public class Beans {
 
     public static void setDesignTime(boolean isDesignTime)
                         throws SecurityException {
+        @SuppressWarnings("removal")
         SecurityManager sm = System.getSecurityManager();
         if (sm != null) {
             sm.checkPropertiesAccess();
@@ -461,7 +468,7 @@ public class Beans {
      * method is called. This could result in a SecurityException.
      *
      * @param isGuiAvailable  True if GUI interaction is available.
-     * @exception  SecurityException  if a security manager exists and its
+     * @throws  SecurityException  if a security manager exists and its
      *             {@code checkPropertiesAccess} method doesn't allow setting
      *              of system properties.
      * @see SecurityManager#checkPropertiesAccess
@@ -469,6 +476,7 @@ public class Beans {
 
     public static void setGuiAvailable(boolean isGuiAvailable)
                         throws SecurityException {
+        @SuppressWarnings("removal")
         SecurityManager sm = System.getSecurityManager();
         if (sm != null) {
             sm.checkPropertiesAccess();
@@ -516,7 +524,8 @@ class ObjectInputStreamWithLoader extends ObjectInputStream
  * Package private support class.  This provides a default AppletContext
  * for beans which are applets.
  */
-@Deprecated(since = "9")
+@Deprecated(since = "9", forRemoval = true)
+@SuppressWarnings("removal")
 class BeansAppletContext implements AppletContext {
     Applet target;
     Hashtable<URL,Object> imageCache = new Hashtable<>();
@@ -601,7 +610,8 @@ class BeansAppletContext implements AppletContext {
  * Package private support class.  This provides an AppletStub
  * for beans which are applets.
  */
-@Deprecated(since = "9")
+@Deprecated(since = "9", forRemoval = true)
+@SuppressWarnings("removal")
 class BeansAppletStub implements AppletStub {
     transient boolean active;
     transient Applet target;
