@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "22.0.2";
+        "23";
 
     private static final String java_version_date =
-        "2024-07-16";
+        "2024-09-17";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,16 +49,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "22.0.2+9";
+        "23";
 
     private static final String VERSION_NUMBER =
-        "22.0.2";
+        "23";
 
     private static final String VERSION_SPECIFICATION =
-        "22";
+        "23";
 
     private static final String VERSION_BUILD =
-        "9";
+        "";
 
     private static final String VERSION_PRE =
         "";
@@ -70,7 +70,7 @@ class VersionProps {
         "".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "66.0";
+        "67.0";
 
     private static final String VENDOR =
         "Arch Linux";
