@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -72,16 +68,11 @@ public class CurrencyNames_cs extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
             { "AUD", "AU$" },
-            { "CNH", "CNH" },
             { "CSK", "K\u010ds" },
             { "CZK", "K\u010d" },
             { "ILS", "ILS" },
             { "INR", "INR" },
-            { "KRH", "KRH" },
-            { "KRO", "KRO" },
-            { "MRU", "MRU" },
-            { "STN", "STN" },
-            { "VES", "VES" },
+            { "PHP", "PHP" },
             { "VND", "VND" },
             { "XEU", "ECU" },
             { "XXX", "XXX" },
@@ -309,7 +300,8 @@ public class CurrencyNames_cs extends OpenListResourceBundle {
             { "shp", "svatohelensk\u00e1 libra" },
             { "sit", "slovinsk\u00fd tolar" },
             { "skk", "slovensk\u00e1 koruna" },
-            { "sll", "sierro-leonsk\u00fd leone" },
+            { "sle", "sierro-leonsk\u00fd leone" },
+            { "sll", "sierro-leonsk\u00fd leone (1964\u20142022)" },
             { "sos", "som\u00e1lsk\u00fd \u0161ilink" },
             { "srd", "surinamsk\u00fd dolar" },
             { "srg", "surinamsk\u00fd zlat\u00fd" },
