@@ -178,14 +178,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Casey = new String[] {
-               "Caseyko ordua",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Chile = new String[] {
                "Txileko ordu estandarra",
                "",
@@ -220,11 +212,11 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             };
         final String[] India = new String[] {
                "Indiako ordua",
+               "IST",
                "",
+               "IST",
                "",
-               "",
-               "",
-               "",
+               "IST",
             };
         final String[] Japan = new String[] {
                "Japoniako ordu estandarra",
@@ -324,11 +316,11 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Azoreetako ordu estandarra",
-               "HMT",
+               "",
                "Azoreetako udako ordua",
-               "HMT",
+               "",
                "Azoreetako ordua",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "Bhutango ordua",
@@ -988,11 +980,11 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Afrikako erdialdeko ordua",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "Afrikako ekialdeko ordua",
@@ -1138,14 +1130,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Mexikoko ipar-ekialdeko ordu estandarra",
-               "",
-               "Mexikoko ipar-ekialdeko udako ordua",
-               "",
-               "Mexikoko ipar-ekialdeko ordua",
-               "",
-            };
         final String[] Papua_New_Guinea = new String[] {
                "Papua Ginea Berriko ordua",
                "",
@@ -1172,27 +1156,11 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             };
         final String[] Australia_Western = new String[] {
                "Australiako mendebaldeko ordu estandarra",
-               "",
+               "AWST",
                "Australiako mendebaldeko udako ordua",
-               "",
+               "AWDT",
                "Australiako mendebaldeko ordua",
-               "",
-            };
-        final String[] Greenland_Eastern = new String[] {
-               "Groenlandiako ekialdeko ordu estandarra",
-               "",
-               "Groenlandiako ekialdeko udako ordua",
-               "",
-               "Groenlandiako ekialdeko ordua",
-               "",
-            };
-        final String[] Greenland_Western = new String[] {
-               "Groenlandiako mendebaldeko ordu estandarra",
-               "",
-               "Groenlandiako mendebaldeko udako ordua",
-               "",
-               "Groenlandiako mendebaldeko ordua",
-               "",
+               "AWT",
             };
         final String[] Indonesia_Central = new String[] {
                "Indonesiako erdialdeko ordua",
@@ -1218,14 +1186,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "",
                "WIB",
             };
-        final String[] Kazakhstan_Eastern = new String[] {
-               "Kazakhstango ekialdeko ordua",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Kazakhstan_Western = new String[] {
                "Kazakhstango mendebaldeko ordua",
                "",
@@ -1270,8 +1230,20 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
             { "UTC", ETC_UTC },
+            { "GB",
+                new String[] {
+                    "Greenwichko meridianoaren ordua",
+                    "GMT",
+                    "Londresko udako ordua",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "NZ", New_Zealand },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "BET", Brasilia },
@@ -1282,21 +1254,103 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "CTT", China },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "IET", America_Eastern },
+            { "IST", India },
             { "JST", Japan },
             { "MIT", Apia },
             { "NET", Armenia },
             { "NST", New_Zealand },
             { "PLT", Pakistan },
             { "PNT", America_Mountain },
+            { "PRC", China },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "ROK", Korea },
             { "SST", Solomon },
+            { "UCT",
+                new String[] {
+                    "ordu unibertsal koordinatua",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "VST", Indochina },
+            { "Cuba", Cuba },
+            { "Eire",
+                new String[] {
+                    "Greenwichko meridianoaren ordua",
+                    "GMT",
+                    "Irlandako ordu estandarra",
+                    "IST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "GMT0", GMT },
+            { "Iran", Iran },
+            { "W-SU", Moscow },
+            { "Zulu",
+                new String[] {
+                    "ordu unibertsal koordinatua",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Japan", Japan },
+            { "Libya", Europe_Eastern },
+            { "Israel", Israel },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "ordu unibertsal koordinatua",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Etc/UTC", ETC_UTC },
+            { "GB-Eire",
+                new String[] {
+                    "Greenwichko meridianoaren ordua",
+                    "GMT",
+                    "Londresko udako ordua",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
+            { "NZ-CHAT", Chatham },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "ordu unibertsal koordinatua",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Hongkong", Hong_Kong },
+            { "Portugal", Europe_Western },
+            { "US/Samoa", Samoa },
             { "Asia/Aden", Arabian },
             { "Asia/Baku", Azerbaijan },
             { "Asia/Dili", East_Timor },
@@ -1304,17 +1358,49 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Kwajalein", Marshall_Islands },
+            { "Singapore", Singapore },
+            { "US/Alaska", Alaska },
+            { "US/Hawaii",
+                new String[] {
+                    "Hawaii-Aleutiar uharteetako ordu estandarra",
+                    "HST",
+                    "Hawaii-Aleutiar uharteetako udako ordua",
+                    "HDT",
+                    "Hawaii-Aleutiar uharteetako ordua",
+                    "HST",
+                }
+            },
+            { "Universal",
+                new String[] {
+                    "ordu unibertsal koordinatua",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Dubai", Gulf },
             { "Asia/Kabul", Afghanistan },
+            { "Asia/Macao", China },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
-            { "Asia/Almaty", Kazakhstan_Eastern },
+            { "Asia/Almaty", Kazakhstan_Western },
             { "Asia/Anadyr", Anadyr },
             { "Asia/Aqtobe", Kazakhstan_Western },
             { "Asia/Atyrau", Kazakhstan_Western },
@@ -1329,12 +1415,21 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Asia/Saigon", Indochina },
             { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
+            { "Asia/Thimbu", Bhutan },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/Acre", Acre },
+            { "Brazil/East", Brasilia },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Indian/Mahe", Seychelles },
-            { "Pacific/Yap", Truk },
+            { "Pacific/Yap", Papua_New_Guinea },
+            { "US/Aleutian", Hawaii_Aleutian },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -1342,6 +1437,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
             { "America/Adak", Hawaii_Aleutian },
+            { "America/Atka", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
             { "Asia/Baghdad", Arabian },
@@ -1352,7 +1448,8 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Asia/Irkutsk", Irkutsk },
             { "Asia/Jakarta", Indonesia_Western },
             { "Asia/Karachi", Pakistan },
-            { "Asia/Kuching", Malaysia },
+            { "Asia/Kolkata", India },
+            { "Asia/Kuching", Brunei },
             { "Asia/Magadan", Magadan },
             { "Asia/Nicosia", Europe_Eastern },
             { "Asia/Rangoon", Myanmar },
@@ -1360,6 +1457,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Asia/Thimphu", Bhutan },
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
+            { "Canada/Yukon", Yukon },
             { "Europe/Malta", Europe_Central },
             { "Europe/Minsk", Moscow },
             { "Europe/Sofia", Europe_Eastern },
@@ -1377,6 +1475,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "SystemV/MST7", America_Mountain },
             { "SystemV/PST8", Pitcairn },
             { "SystemV/YST9", Gambier },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bamako", GMT },
             { "Africa/Bangui", Africa_Western },
@@ -1404,10 +1503,25 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Western },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
+            { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/LHI", Lord_Howe },
+            { "Australia/NSW", Australia_Eastern },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "ordu unibertsal koordinatua",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
@@ -1420,7 +1534,16 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
-            { "Europe/Jersey", GMT },
+            { "Europe/Jersey",
+                new String[] {
+                    "Greenwichko meridianoaren ordua",
+                    "GMT",
+                    "Londresko udako ordua",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -1445,9 +1568,11 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Indian/Chagos", Indian_Ocean },
             { "Indian/Comoro", Africa_Eastern },
+            { "Pacific/Chuuk", Papua_New_Guinea },
             { "Pacific/Efate", Vanuatu },
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
+            { "Pacific/Samoa", Samoa },
             { "SystemV/HST10",
                 new String[] {
                     "Hawaii-Aleutiar uharteetako ordu estandarra",
@@ -1483,15 +1608,24 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
+            { "Asia/Chungking", China },
             { "Asia/Hong_Kong", Hong_Kong },
             { "Asia/Kamchatka", Kamchatka },
+            { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
             { "Asia/Pyongyang", Korea },
             { "Asia/Qyzylorda", Kazakhstan_Western },
             { "Asia/Samarkand", Uzbekistan },
             { "Asia/Singapore", Singapore },
             { "Asia/Vientiane", Indochina },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -1503,21 +1637,25 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "Indian/Reunion", Reunion },
+            { "Mexico/BajaSur", Mexico_Pacific },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kanton", Phoenix_Islands },
             { "Pacific/Kosrae", Kosrae },
             { "Pacific/Majuro", Marshall_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
-            { "Pacific/Ponape", Ponape },
+            { "Pacific/Ponape", Solomon },
             { "Pacific/Saipan", Chamorro },
             { "Pacific/Tahiti", Tahiti },
-            { "Pacific/Tarawa", Gilbert_Islands },
-            { "Pacific/Wallis", Wallis },
+            { "Pacific/Tarawa", Marshall_Islands },
+            { "Pacific/Wallis", Gilbert_Islands },
             { "Africa/Blantyre", Africa_Central },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Freetown", GMT },
@@ -1536,10 +1674,10 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Godthab", Greenland_Western },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
@@ -1553,25 +1691,41 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Yakutat", Alaska },
             { "Asia/Choibalsan", Mongolia },
             { "Asia/Phnom_Penh", Indochina },
+            { "Asia/Ulan_Bator", Mongolia },
             { "Atlantic/Azores", Azores },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/North", Australia_Central },
             { "Australia/Perth", Australia_Western },
+            { "Australia/South", Australia_Central },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/Guernsey", GMT },
+            { "Europe/Guernsey",
+                new String[] {
+                    "Greenwichko meridianoaren ordua",
+                    "GMT",
+                    "Londresko udako ordua",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
-            { "Indian/Maldives", Maldives },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
             { "Pacific/Fakaofo", Tokelau },
             { "Pacific/Gambier", Gambier },
             { "Pacific/Norfolk", Norfolk },
+            { "Pacific/Pohnpei", Solomon },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
@@ -1582,10 +1736,12 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Africa/Mogadishu", Africa_Eastern },
             { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
             { "America/Eirunepe", Acre },
+            { "America/Ensenada", America_Pacific },
             { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
@@ -1596,10 +1752,11 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
+            { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1611,6 +1768,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
@@ -1621,9 +1779,19 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
-            { "Pacific/Johnston", Hawaii_Aleutian },
+            { "Pacific/Johnston",
+                new String[] {
+                    "Hawaii-Aleutiar uharteetako ordu estandarra",
+                    "HST",
+                    "Hawaii-Aleutiar uharteetako udako ordua",
+                    "HDT",
+                    "Hawaii-Aleutiar uharteetako ordua",
+                    "HST",
+                }
+            },
             { "Pacific/Pitcairn", Pitcairn },
             { "Africa/Libreville", Africa_Western },
             { "Africa/Lubumbashi", Africa_Central },
@@ -1648,6 +1816,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Antarctica/Vostok", Vostok },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Chile/Continental", Chile },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
             { "Europe/Luxembourg", Europe_Central },
@@ -1661,6 +1830,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Pacific/Pago_Pago", Samoa },
             { "Pacific/Rarotonga", Cook },
             { "Pacific/Tongatapu", Tonga },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "Africa/Ouagadougou", GMT },
@@ -1675,19 +1845,34 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Montevideo", Uruguay },
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
+            { "America/Porto_Acre", Acre },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
             { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
             { "Australia/Adelaide", Australia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
-            { "Europe/Isle_of_Man", GMT },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "Greenwichko meridianoaren ordua",
+                    "GMT",
+                    "Londresko udako ordua",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "Pacific/Kiritimati", Line_Islands },
             { "Africa/Johannesburg", Africa_Southern },
@@ -1705,6 +1890,8 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Pacific/Guadalcanal", Solomon },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
@@ -1715,10 +1902,11 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Santa_Isabel", Mexico_Northwest },
-            { "America/Scoresbysund", Greenland_Eastern },
+            { "America/Santa_Isabel", America_Pacific },
             { "Antarctica/Macquarie", Australia_Eastern },
-            { "Pacific/Port_Moresby", Papua_New_Guinea },
+            { "Australia/Queensland", Australia_Eastern },
+            { "Australia/Yancowinna", Australia_Central },
+            { "Pacific/Port_Moresby", DumontDUrville },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1733,9 +1921,12 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
             { "Atlantic/South_Georgia", South_Georgia },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -1751,6 +1942,8 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Macau", "Macau" },
             { "timezone.excity.Asia/Seoul", "Seul" },
             { "timezone.excity.Asia/Tokyo", "Tokio" },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
@@ -1763,6 +1956,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Kiev", "Kiev" },
             { "timezone.excity.Europe/Rome", "Erroma" },
             { "timezone.excity.Indian/Mahe", "Mah\u00e9" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Africa/Accra", "Akkra" },
             { "timezone.excity.Africa/Cairo", "Kairo" },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
@@ -1796,6 +1990,7 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Warsaw", "Varsovia" },
             { "timezone.excity.Europe/Zurich", "Z\u00fcrich" },
             { "timezone.excity.Pacific/Efate", "\u00c9fat\u00e9" },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Algiers", "Aljer" },
@@ -1826,7 +2021,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Brussels", "Brusela" },
             { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
             { "timezone.excity.Europe/Guernsey", "Guernesey" },
-            { "timezone.excity.Europe/Uzhgorod", "Uzhhorod" },
             { "timezone.excity.Indian/Maldives", "Maldivak" },
             { "timezone.excity.Africa/Mogadishu", "Muqdisho" },
             { "timezone.excity.America/Anguilla", "Aingira" },
@@ -1840,7 +2034,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "timezone.excity.America/St_Lucia", "Santa Luzia" },
             { "timezone.excity.Asia/Krasnoyarsk", "Krasnoiarsk" },
             { "timezone.excity.Asia/Ulaanbaatar", "Ulan Bator" },
-            { "timezone.excity.Australia/Currie", "Currie" },
             { "timezone.excity.Europe/Bucharest", "Bukarest" },
             { "timezone.excity.Europe/Ulyanovsk", "Ulianovsk" },
             { "timezone.excity.Indian/Mauritius", "Maurizio" },
@@ -1852,7 +2045,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "timezone.excity.America/St_Thomas", "Saint-Thomas" },
             { "timezone.excity.Europe/Copenhagen", "Kopenhage" },
             { "timezone.excity.Europe/Luxembourg", "Luxenburgo" },
-            { "timezone.excity.Europe/Zaporozhye", "Zaporizhia" },
             { "timezone.excity.Pacific/Enderbury", "Enderbury" },
             { "timezone.excity.Pacific/Galapagos", "Galapagoak" },
             { "timezone.excity.Pacific/Marquesas", "Markesak" },
@@ -1867,7 +2059,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Isle_of_Man", "Man uhartea" },
             { "timezone.excity.America/Mexico_City", "Mexiko Hiria" },
             { "timezone.excity.Atlantic/Cape_Verde", "Cabo Verde" },
-            { "timezone.excity.America/Santa_Isabel", "Santa Isabel" },
             { "timezone.excity.America/Port_of_Spain", "Port-of-Spain" },
             { "timezone.excity.America/St_Barthelemy", "Saint-Barth\u00e9lemy" },
             { "timezone.excity.Atlantic/South_Georgia", "Hegoaldeko Georgiak" },
