@@ -204,11 +204,11 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             };
         final String[] India = new String[] {
                "Saeta Standard a Hindistan\u00ea",
+               "IST",
                "",
+               "IST",
                "",
-               "",
-               "",
-               "",
+               "IST",
             };
         final String[] Japan = new String[] {
                "Saeta Standard a Japonyay\u00ea",
@@ -300,11 +300,11 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Saeta Standard a Azoran",
-               "HMT",
+               "",
                "Saeta Hav\u00een\u00ea ya Azoran",
-               "HMT",
+               "",
                "Saeta Azoran",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "Saeta B\u00fbtan\u00ea",
@@ -948,11 +948,11 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Saeta Afr\u00eekaya Nav\u00een",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "Saeta Afr\u00eekaya Rojhilat",
@@ -996,19 +996,19 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             };
         final String[] Europe_Western = new String[] {
                "Saeta Standard a Ewropaya Rojava",
-               "FMT",
+               "WET",
                "Saeta Hav\u00een\u00ea ya Ewropaya Rojava",
-               "FMT",
+               "WEST",
                "Saeta Ewropaya Rojava",
-               "FMT",
+               "WET",
             };
         final String[] Mexico_Pacific = new String[] {
                "Saeta Standard a Pas\u00eef\u00eeka Meks\u00eekay\u00ea",
-               "SSPM",
+               "MST",
                "Saeta Hav\u00een\u00ea ya Pas\u00eef\u00eeka Meks\u00eekay\u00ea",
-               "SHPM",
+               "MDT",
                "Saeta Pas\u00eef\u00eeka Meks\u00eekay\u00ea",
-               "SPM",
+               "MT",
             };
         final String[] Africa_Southern = new String[] {
                "Saeta Standard a Afr\u00eekaya Ba\u015f\u00fbr",
@@ -1076,11 +1076,11 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             };
         final String[] Pierre_Miquelon = new String[] {
                "Saeta Standard a Saint Pierre \u00fb Miquelon\u00ea",
-               "SSSPM",
+               "",
                "Saeta Hav\u00een\u00ea ya Saint Pierre \u00fb Miquelon\u00ea",
-               "SHSPM",
+               "",
                "Saeta Saint Pierre \u00fb Miquelon\u00ea",
-               "SSPM",
+               "",
             };
         final String[] America_Mountain = new String[] {
                "Saeta Standard a \u00c7iyay\u00ee ya Amer\u00eekaya Bakur",
@@ -1098,14 +1098,6 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Saeta Standard a Meks\u00eekoya Bakurrojava",
-               "SSMBR",
-               "Saeta Hav\u00een\u00ea ya Meks\u00eekoya Bakurrojava",
-               "SHMBR",
-               "Saeta Meks\u00eekoya Bakurrojava",
-               "SMBR",
-            };
         final String[] Papua_New_Guinea = new String[] {
                "Saeta G\u00eeneya N\u00fb ya Pap\u00fbay\u00ea",
                "",
@@ -1132,27 +1124,11 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             };
         final String[] Australia_Western = new String[] {
                "Saeta Standard a Awistralyaya Rojava",
-               "",
+               "AWST",
                "Saeta Hav\u00een\u00ea ya Awistralyaya Rojava",
-               "",
+               "AWDT",
                "Saeta Awistralyaya Rojava",
-               "",
-            };
-        final String[] Greenland_Eastern = new String[] {
-               "Saeta Standard a Gr\u00eenlanda Rojhilat",
-               "SSGR",
-               "Saeta Hav\u00een\u00ea ya Gr\u00eenlanda Rojhilat",
-               "SHGR",
-               "Saeta Gr\u00eenlanda Rojhilat",
-               "SGR",
-            };
-        final String[] Greenland_Western = new String[] {
-               "Saeta Standard a Gr\u00eenlanda Rojava",
-               "SSGRO",
-               "Saeta Hav\u00een\u00ea ya Gr\u00eenlanda Rojava",
-               "SHGRO",
-               "Saeta Gr\u00eenlanda Rojava",
-               "SGRO",
+               "AWT",
             };
         final String[] Indonesia_Central = new String[] {
                "Saeta Endonezyaya Nav\u00een",
@@ -1178,14 +1154,6 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
                "",
                "WIB",
             };
-        final String[] Kazakhstan_Eastern = new String[] {
-               "Saeta Qazaxistana Rojhilat",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Kazakhstan_Western = new String[] {
                "Saeta Qazaxistana Rojava",
                "",
@@ -1221,8 +1189,20 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
             { "UTC", ETC_UTC },
+            { "GB",
+                new String[] {
+                    "Saeta Nav\u00een\u00ee ya Greenwich\u00ea",
+                    "GMT",
+                    "Saeta Hav\u00een\u00ea ya Bir\u00eetanyay\u00ea",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "NZ", New_Zealand },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "BET", Brasilia },
@@ -1233,21 +1213,103 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "CTT", China },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "IET", America_Eastern },
+            { "IST", India },
             { "JST", Japan },
             { "MIT", Apia },
             { "NET", Armenia },
             { "NST", New_Zealand },
             { "PLT", Pakistan },
             { "PNT", America_Mountain },
+            { "PRC", China },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "ROK", Korea },
             { "SST", Solomon },
+            { "UCT",
+                new String[] {
+                    "Saeta Gerd\u00fbn\u00ee ya Hevdem\u00ee",
+                    "SGH",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "VST", Indochina },
+            { "Cuba", Cuba },
+            { "Eire",
+                new String[] {
+                    "Saeta Nav\u00een\u00ee ya Greenwich\u00ea",
+                    "GMT",
+                    "Saeta Standard a \u00cerlanday\u00ea",
+                    "IST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "GMT0", GMT },
+            { "Iran", Iran },
+            { "W-SU", Moscow },
+            { "Zulu",
+                new String[] {
+                    "Saeta Gerd\u00fbn\u00ee ya Hevdem\u00ee",
+                    "SGH",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Japan", Japan },
+            { "Libya", Europe_Eastern },
+            { "Israel", Israel },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "Saeta Gerd\u00fbn\u00ee ya Hevdem\u00ee",
+                    "SGH",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Etc/UTC", ETC_UTC },
+            { "GB-Eire",
+                new String[] {
+                    "Saeta Nav\u00een\u00ee ya Greenwich\u00ea",
+                    "GMT",
+                    "Saeta Hav\u00een\u00ea ya Bir\u00eetanyay\u00ea",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
+            { "NZ-CHAT", Chatham },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "Saeta Gerd\u00fbn\u00ee ya Hevdem\u00ee",
+                    "SGH",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Hongkong", Hong_Kong },
+            { "Portugal", Europe_Western },
+            { "US/Samoa", Samoa },
             { "Asia/Aden", Arabian },
             { "Asia/Baku", Azerbaijan },
             { "Asia/Dili", East_Timor },
@@ -1255,17 +1317,40 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Kwajalein", Marshall_Islands },
+            { "Singapore", Singapore },
+            { "US/Alaska", Alaska },
+            { "US/Hawaii", Hawaii_Aleutian },
+            { "Universal",
+                new String[] {
+                    "Saeta Gerd\u00fbn\u00ee ya Hevdem\u00ee",
+                    "SGH",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Dubai", Gulf },
             { "Asia/Kabul", Afghanistan },
+            { "Asia/Macao", China },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
-            { "Asia/Almaty", Kazakhstan_Eastern },
+            { "Asia/Almaty", Kazakhstan_Western },
             { "Asia/Aqtobe", Kazakhstan_Western },
             { "Asia/Atyrau", Kazakhstan_Western },
             { "Asia/Beirut", Europe_Eastern },
@@ -1279,12 +1364,20 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Asia/Saigon", Indochina },
             { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
+            { "Asia/Thimbu", Bhutan },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/East", Brasilia },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Indian/Mahe", Seychelles },
-            { "Pacific/Yap", Truk },
+            { "Pacific/Yap", Papua_New_Guinea },
+            { "US/Aleutian", Hawaii_Aleutian },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -1292,6 +1385,7 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
             { "America/Adak", Hawaii_Aleutian },
+            { "America/Atka", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
             { "Asia/Baghdad", Arabian },
@@ -1302,7 +1396,8 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Asia/Irkutsk", Irkutsk },
             { "Asia/Jakarta", Indonesia_Western },
             { "Asia/Karachi", Pakistan },
-            { "Asia/Kuching", Malaysia },
+            { "Asia/Kolkata", India },
+            { "Asia/Kuching", Brunei },
             { "Asia/Magadan", Magadan },
             { "Asia/Nicosia", Europe_Eastern },
             { "Asia/Rangoon", Myanmar },
@@ -1310,6 +1405,7 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Asia/Thimphu", Bhutan },
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
+            { "Canada/Yukon", Yukon },
             { "Europe/Malta", Europe_Central },
             { "Europe/Minsk", Moscow },
             { "Europe/Sofia", Europe_Eastern },
@@ -1327,6 +1423,7 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "SystemV/MST7", America_Mountain },
             { "SystemV/PST8", Pitcairn },
             { "SystemV/YST9", Gambier },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bamako", GMT },
             { "Africa/Bangui", Africa_Western },
@@ -1354,10 +1451,25 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Western },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
+            { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/LHI", Lord_Howe },
+            { "Australia/NSW", Australia_Eastern },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "Saeta Gerd\u00fbn\u00ee ya Hevdem\u00ee",
+                    "SGH",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
@@ -1370,7 +1482,16 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
-            { "Europe/Jersey", GMT },
+            { "Europe/Jersey",
+                new String[] {
+                    "Saeta Nav\u00een\u00ee ya Greenwich\u00ea",
+                    "GMT",
+                    "Saeta Hav\u00een\u00ea ya Bir\u00eetanyay\u00ea",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -1394,9 +1515,11 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Indian/Chagos", Indian_Ocean },
             { "Indian/Comoro", Africa_Eastern },
+            { "Pacific/Chuuk", Papua_New_Guinea },
             { "Pacific/Efate", Vanuatu },
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
+            { "Pacific/Samoa", Samoa },
             { "SystemV/HST10", Hawaii_Aleutian },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
@@ -1423,14 +1546,23 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
+            { "Asia/Chungking", China },
             { "Asia/Hong_Kong", Hong_Kong },
+            { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
             { "Asia/Pyongyang", Korea },
             { "Asia/Qyzylorda", Kazakhstan_Western },
             { "Asia/Samarkand", Uzbekistan },
             { "Asia/Singapore", Singapore },
             { "Asia/Vientiane", Indochina },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -1442,21 +1574,25 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "Indian/Reunion", Reunion },
+            { "Mexico/BajaSur", Mexico_Pacific },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kanton", Phoenix_Islands },
             { "Pacific/Kosrae", Kosrae },
             { "Pacific/Majuro", Marshall_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
-            { "Pacific/Ponape", Ponape },
+            { "Pacific/Ponape", Solomon },
             { "Pacific/Saipan", Chamorro },
             { "Pacific/Tahiti", Tahiti },
-            { "Pacific/Tarawa", Gilbert_Islands },
-            { "Pacific/Wallis", Wallis },
+            { "Pacific/Tarawa", Marshall_Islands },
+            { "Pacific/Wallis", Gilbert_Islands },
             { "Africa/Blantyre", Africa_Central },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Freetown", GMT },
@@ -1475,10 +1611,10 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Godthab", Greenland_Western },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
@@ -1492,25 +1628,41 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "America/Yakutat", Alaska },
             { "Asia/Choibalsan", Mongolia },
             { "Asia/Phnom_Penh", Indochina },
+            { "Asia/Ulan_Bator", Mongolia },
             { "Atlantic/Azores", Azores },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/North", Australia_Central },
             { "Australia/Perth", Australia_Western },
+            { "Australia/South", Australia_Central },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/Guernsey", GMT },
+            { "Europe/Guernsey",
+                new String[] {
+                    "Saeta Nav\u00een\u00ee ya Greenwich\u00ea",
+                    "GMT",
+                    "Saeta Hav\u00een\u00ea ya Bir\u00eetanyay\u00ea",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
-            { "Indian/Maldives", Maldives },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
             { "Pacific/Fakaofo", Tokelau },
             { "Pacific/Gambier", Gambier },
             { "Pacific/Norfolk", Norfolk },
+            { "Pacific/Pohnpei", Solomon },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
@@ -1521,9 +1673,11 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Africa/Mogadishu", Africa_Eastern },
             { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Ensenada", America_Pacific },
             { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
@@ -1534,9 +1688,11 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
+            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
+            { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1548,6 +1704,7 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
@@ -1558,6 +1715,7 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
             { "Pacific/Johnston", Hawaii_Aleutian },
@@ -1585,6 +1743,7 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Antarctica/Vostok", Vostok },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Chile/Continental", Chile },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
             { "Europe/Luxembourg", Europe_Central },
@@ -1598,6 +1757,7 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Pacific/Pago_Pago", Samoa },
             { "Pacific/Rarotonga", Cook },
             { "Pacific/Tongatapu", Tonga },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "Africa/Ouagadougou", GMT },
@@ -1616,14 +1776,28 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
             { "Australia/Adelaide", Australia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
-            { "Europe/Isle_of_Man", GMT },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "Saeta Nav\u00een\u00ee ya Greenwich\u00ea",
+                    "GMT",
+                    "Saeta Hav\u00een\u00ea ya Bir\u00eetanyay\u00ea",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "Pacific/Kiritimati", Line_Islands },
             { "Africa/Johannesburg", Africa_Southern },
@@ -1641,6 +1815,8 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Pacific/Guadalcanal", Solomon },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
@@ -1651,10 +1827,11 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Santa_Isabel", Mexico_Northwest },
-            { "America/Scoresbysund", Greenland_Eastern },
+            { "America/Santa_Isabel", America_Pacific },
             { "Antarctica/Macquarie", Australia_Eastern },
-            { "Pacific/Port_Moresby", Papua_New_Guinea },
+            { "Australia/Queensland", Australia_Eastern },
+            { "Australia/Yancowinna", Australia_Central },
+            { "Pacific/Port_Moresby", DumontDUrville },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1669,9 +1846,12 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
             { "Atlantic/South_Georgia", South_Georgia },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -1693,6 +1873,8 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Macau", "Makao" },
             { "timezone.excity.Asia/Qatar", "Qeter" },
             { "timezone.excity.Asia/Seoul", "Se\u00fbl" },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
@@ -1713,6 +1895,7 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Kiev", "K\u00eeev" },
             { "timezone.excity.Europe/Riga", "R\u00eega" },
             { "timezone.excity.Europe/Rome", "Roma" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Africa/Accra", "Akra" },
             { "timezone.excity.Africa/Cairo", "Qah\u00eere" },
             { "timezone.excity.Africa/Ceuta", "Septe" },
@@ -1761,6 +1944,7 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Warsaw", "War\u015fova" },
             { "timezone.excity.Europe/Zurich", "Z\u00fbr\u00eeh" },
             { "timezone.excity.Indian/Comoro", "Komor" },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Algiers", "Cezay\u00eer" },
@@ -1796,7 +1980,6 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Helsinki", "Hels\u00eenk\u00ee" },
             { "timezone.excity.Europe/Istanbul", "Stenbol" },
             { "timezone.excity.Europe/Sarajevo", "Saraybosna" },
-            { "timezone.excity.Europe/Uzhgorod", "Ujgorod" },
             { "timezone.excity.Indian/Maldives", "Mald\u00eev" },
             { "timezone.excity.Africa/Mogadishu", "Mogad\u00ee\u015f\u00fb" },
             { "timezone.excity.America/Dominica", "Dom\u00een\u00eeka" },
@@ -1815,7 +1998,6 @@ public class TimeZoneNames_ku extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Copenhagen", "Kopenhag" },
             { "timezone.excity.Europe/Luxembourg", "Luksemb\u00fbrg" },
             { "timezone.excity.Europe/San_Marino", "San Mar\u00eeno" },
-            { "timezone.excity.Europe/Zaporozhye", "Zaporojye" },
             { "timezone.excity.America/Costa_Rica", "Kosta R\u00eeka" },
             { "timezone.excity.Europe/Isle_of_Man", "Girava Man\u00ea" },
             { "timezone.excity.Europe/Kaliningrad", "Kal\u00een\u00eengrad" },
