@@ -116,25 +116,40 @@ public class TimeZoneNames_os extends TimeZoneNamesBundle {
             };
         final String[] Europe_Western = new String[] {
                "\u041d\u044b\u0433\u044a\u0443\u044b\u043b\u04d5\u043d \u0415\u0432\u0440\u043e\u043f\u04d5\u0439\u0430\u0433 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u043e\u043d \u0440\u04d5\u0441\u0442\u04d5\u0433",
-               "FMT",
+               "WET",
                "\u041d\u044b\u0433\u044a\u0443\u044b\u043b\u04d5\u043d \u0415\u0432\u0440\u043e\u043f\u04d5\u0439\u0430\u0433 \u0441\u04d5\u0440\u0434\u044b\u0433\u043e\u043d \u0440\u04d5\u0441\u0442\u04d5\u0433",
-               "FMT",
+               "WEST",
                "\u041d\u044b\u0433\u044a\u0443\u044b\u043b\u04d5\u043d \u0415\u0432\u0440\u043e\u043f\u04d5\u0439\u0430\u0433 \u0440\u04d5\u0441\u0442\u04d5\u0433",
-               "FMT",
+               "WET",
             };
         final Object[][] data = new Object[][] {
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
             { "Europe/Bucharest", Europe_Eastern },
             { "UTC", EMPTY_ZONE },
+            { "GB", GMT },
             { "ART", Europe_Eastern },
             { "ECT", Europe_Central },
+            { "Eire", GMT },
+            { "GMT0", GMT },
+            { "W-SU", Moscow },
+            { "Egypt", Europe_Eastern },
+            { "Libya", Europe_Eastern },
+            { "Poland", Europe_Central },
             { "Etc/GMT", GMT },
+            { "GB-Eire", GMT },
+            { "Iceland", GMT },
+            { "Etc/GMT0", GMT },
+            { "Portugal", Europe_Western },
             { "Asia/Gaza", Europe_Eastern },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
@@ -152,6 +167,7 @@ public class TimeZoneNames_os extends TimeZoneNamesBundle {
             { "Africa/Bamako", GMT },
             { "Africa/Banjul", GMT },
             { "Africa/Bissau", GMT },
+            { "Etc/Greenwich", GMT },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin", GMT },
@@ -172,8 +188,10 @@ public class TimeZoneNames_os extends TimeZoneNamesBundle {
             { "Africa/Algiers", Europe_Central },
             { "Africa/Conakry", GMT },
             { "Africa/Tripoli", Europe_Eastern },
+            { "Atlantic/Faroe", Europe_Western },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast", GMT },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
@@ -191,6 +209,7 @@ public class TimeZoneNames_os extends TimeZoneNamesBundle {
             { "Europe/Guernsey", GMT },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
             { "Antarctica/Troll", GMT },
             { "Atlantic/Madeira", Europe_Western },
