@@ -204,11 +204,11 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             };
         final String[] India = new String[] {
                "India d\u00e1lve\u00e1igi",
+               "IST",
                "",
+               "IST",
                "",
-               "",
-               "",
-               "",
+               "IST",
             };
         final String[] Japan = new String[] {
                "Jap\u00e1na d\u00e1lve\u00e1igi",
@@ -276,11 +276,11 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "Alaska d\u00e1lve\u00e1igi",
-               "",
+               "AKST",
                "Alaska geasse\u00e1igi",
-               "",
+               "AKDT",
                "Alaska \u00e1igi",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "Amazona d\u00e1lve\u00e1igi",
@@ -292,11 +292,11 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Azoraid d\u00e1lve\u00e1igi",
-               "HMT",
+               "",
                "Azoraid geasse\u00e1igi",
-               "HMT",
+               "",
                "Azoraid \u00e1igi",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "Bhutana \u00e1igi",
@@ -574,9 +574,9 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
                "atl\u00e1ntala\u0161 d\u00e1lve\u00e1igi",
                "AST",
                "atl\u00e1ntala\u0161 geasse\u00e1igi",
-               "ADT",
+               "AST",
                "atl\u00e1ntala\u0161 \u00e1igi",
-               "AT",
+               "AST",
             };
         final String[] Brasilia = new String[] {
                "Brasilia d\u00e1lve\u00e1igi",
@@ -940,11 +940,11 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Gaska-Afrihk\u00e1 \u00e1igi",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "Nuorta-Afrihk\u00e1 \u00e1igi",
@@ -1078,9 +1078,9 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
                "d\u00e1lveduottar\u00e1igi",
                "MST",
                "geasseduottar\u00e1igi",
-               "MDT",
+               "MST",
                "duottar\u00e1igi",
-               "MT",
+               "MST",
             };
         final String[] Marshall_Islands = new String[] {
                "Marshallsulloid \u00e1igi",
@@ -1090,14 +1090,6 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Oarjedavvi-Meksiko d\u00e1lve\u00e1igi",
-               "",
-               "Oarjedavvi-Meksiko geasse\u00e1igi",
-               "",
-               "Oarjedavvi-Meksiko \u00e1igi",
-               "",
-            };
         final String[] Papua_New_Guinea = new String[] {
                "Papua O\u0111\u0111a-Guinea \u00e1igi",
                "",
@@ -1124,27 +1116,11 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             };
         final String[] Australia_Western = new String[] {
                "Oarje-Austr\u00e1lia d\u00e1lve\u00e1igi",
-               "",
+               "AWST",
                "Oarje-Austr\u00e1lia geasse\u00e1igi",
-               "",
+               "AWDT",
                "Oarje-Austr\u00e1lia \u00e1igi",
-               "",
-            };
-        final String[] Greenland_Eastern = new String[] {
-               "Nuorta-Ruon\u00e1eatnama d\u00e1lve\u00e1igi",
-               "",
-               "Nuorta-Ruon\u00e1eatnama geasse\u00e1igi",
-               "",
-               "Nuorta-Ruon\u00e1eatnama \u00e1igi",
-               "",
-            };
-        final String[] Greenland_Western = new String[] {
-               "Oarje-Ruon\u00e1eatnama d\u00e1lve\u00e1igi",
-               "",
-               "Oarje-Ruon\u00e1eatnama geasse\u00e1igi",
-               "",
-               "Oarje-Ruon\u00e1eatnama \u00e1igi",
-               "",
+               "AWT",
             };
         final String[] Indonesia_Central = new String[] {
                "Gaska-Indonesia \u00e1igi",
@@ -1170,14 +1146,6 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
                "",
                "WIB",
             };
-        final String[] Kazakhstan_Eastern = new String[] {
-               "Nuorta-Kasakstana \u00e1igi",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Kazakhstan_Western = new String[] {
                "Oarje-Kasakstana \u00e1igi",
                "",
@@ -1213,8 +1181,20 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
             { "UTC", ETC_UTC },
+            { "GB",
+                new String[] {
+                    "Greenwicha \u00e1igi",
+                    "GMT",
+                    "Brihtala\u0161 geasse\u00e1igi",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "NZ", New_Zealand },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "BET", Brasilia },
@@ -1225,21 +1205,103 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "CTT", China },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "IET", America_Eastern },
+            { "IST", India },
             { "JST", Japan },
             { "MIT", Apia },
             { "NET", Armenia },
             { "NST", New_Zealand },
             { "PLT", Pakistan },
             { "PNT", America_Mountain },
+            { "PRC", China },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "ROK", Korea },
             { "SST", Solomon },
+            { "UCT",
+                new String[] {
+                    "koordinerejuvvon oktasa\u0161 \u00e1igi",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "VST", Indochina },
+            { "Cuba", Cuba },
+            { "Eire",
+                new String[] {
+                    "Greenwicha \u00e1igi",
+                    "GMT",
+                    "Irl\u00e1nddala\u0161 d\u00e1lve\u00e1igi",
+                    "IST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "GMT0", GMT },
+            { "Iran", Iran },
+            { "W-SU", Moscow },
+            { "Zulu",
+                new String[] {
+                    "koordinerejuvvon oktasa\u0161 \u00e1igi",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Japan", Japan },
+            { "Libya", Europe_Eastern },
+            { "Israel", Israel },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "koordinerejuvvon oktasa\u0161 \u00e1igi",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Etc/UTC", ETC_UTC },
+            { "GB-Eire",
+                new String[] {
+                    "Greenwicha \u00e1igi",
+                    "GMT",
+                    "Brihtala\u0161 geasse\u00e1igi",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
+            { "NZ-CHAT", Chatham },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "koordinerejuvvon oktasa\u0161 \u00e1igi",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Hongkong", Hong_Kong },
+            { "Portugal", Europe_Western },
+            { "US/Samoa", Samoa },
             { "Asia/Aden", Arabian },
             { "Asia/Baku", Azerbaijan },
             { "Asia/Dili", East_Timor },
@@ -1247,17 +1309,40 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Kwajalein", Marshall_Islands },
+            { "Singapore", Singapore },
+            { "US/Alaska", Alaska },
+            { "US/Hawaii", Hawaii_Aleutian },
+            { "Universal",
+                new String[] {
+                    "koordinerejuvvon oktasa\u0161 \u00e1igi",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Dubai", Gulf },
             { "Asia/Kabul", Afghanistan },
+            { "Asia/Macao", China },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
-            { "Asia/Almaty", Kazakhstan_Eastern },
+            { "Asia/Almaty", Kazakhstan_Western },
             { "Asia/Aqtobe", Kazakhstan_Western },
             { "Asia/Atyrau", Kazakhstan_Western },
             { "Asia/Beirut", Europe_Eastern },
@@ -1271,12 +1356,20 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Asia/Saigon", Indochina },
             { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
+            { "Asia/Thimbu", Bhutan },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/East", Brasilia },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Indian/Mahe", Seychelles },
-            { "Pacific/Yap", Truk },
+            { "Pacific/Yap", Papua_New_Guinea },
+            { "US/Aleutian", Hawaii_Aleutian },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -1284,6 +1377,7 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
             { "America/Adak", Hawaii_Aleutian },
+            { "America/Atka", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
             { "Asia/Baghdad", Arabian },
@@ -1294,7 +1388,8 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Asia/Irkutsk", Irkutsk },
             { "Asia/Jakarta", Indonesia_Western },
             { "Asia/Karachi", Pakistan },
-            { "Asia/Kuching", Malaysia },
+            { "Asia/Kolkata", India },
+            { "Asia/Kuching", Brunei },
             { "Asia/Magadan", Magadan },
             { "Asia/Nicosia", Europe_Eastern },
             { "Asia/Rangoon", Myanmar },
@@ -1319,6 +1414,7 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "SystemV/MST7", America_Mountain },
             { "SystemV/PST8", Pitcairn },
             { "SystemV/YST9", Gambier },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bamako", GMT },
             { "Africa/Bangui", Africa_Western },
@@ -1346,10 +1442,25 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Western },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
+            { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/LHI", Lord_Howe },
+            { "Australia/NSW", Australia_Eastern },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "koordinerejuvvon oktasa\u0161 \u00e1igi",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
@@ -1362,7 +1473,16 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
-            { "Europe/Jersey", GMT },
+            { "Europe/Jersey",
+                new String[] {
+                    "Greenwicha \u00e1igi",
+                    "GMT",
+                    "Brihtala\u0161 geasse\u00e1igi",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -1386,9 +1506,11 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Indian/Chagos", Indian_Ocean },
             { "Indian/Comoro", Africa_Eastern },
+            { "Pacific/Chuuk", Papua_New_Guinea },
             { "Pacific/Efate", Vanuatu },
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
+            { "Pacific/Samoa", Samoa },
             { "SystemV/HST10", Hawaii_Aleutian },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
@@ -1414,14 +1536,23 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
+            { "Asia/Chungking", China },
             { "Asia/Hong_Kong", Hong_Kong },
+            { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
             { "Asia/Pyongyang", Korea },
             { "Asia/Qyzylorda", Kazakhstan_Western },
             { "Asia/Samarkand", Uzbekistan },
             { "Asia/Singapore", Singapore },
             { "Asia/Vientiane", Indochina },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -1433,21 +1564,25 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "Indian/Reunion", Reunion },
+            { "Mexico/BajaSur", Mexico_Pacific },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kanton", Phoenix_Islands },
             { "Pacific/Kosrae", Kosrae },
             { "Pacific/Majuro", Marshall_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
-            { "Pacific/Ponape", Ponape },
+            { "Pacific/Ponape", Solomon },
             { "Pacific/Saipan", Chamorro },
             { "Pacific/Tahiti", Tahiti },
-            { "Pacific/Tarawa", Gilbert_Islands },
-            { "Pacific/Wallis", Wallis },
+            { "Pacific/Tarawa", Marshall_Islands },
+            { "Pacific/Wallis", Gilbert_Islands },
             { "Africa/Blantyre", Africa_Central },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Freetown", GMT },
@@ -1466,10 +1601,10 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Godthab", Greenland_Western },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
@@ -1483,25 +1618,41 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "America/Yakutat", Alaska },
             { "Asia/Choibalsan", Mongolia },
             { "Asia/Phnom_Penh", Indochina },
+            { "Asia/Ulan_Bator", Mongolia },
             { "Atlantic/Azores", Azores },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/North", Australia_Central },
             { "Australia/Perth", Australia_Western },
+            { "Australia/South", Australia_Central },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/Guernsey", GMT },
+            { "Europe/Guernsey",
+                new String[] {
+                    "Greenwicha \u00e1igi",
+                    "GMT",
+                    "Brihtala\u0161 geasse\u00e1igi",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
-            { "Indian/Maldives", Maldives },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
             { "Pacific/Fakaofo", Tokelau },
             { "Pacific/Gambier", Gambier },
             { "Pacific/Norfolk", Norfolk },
+            { "Pacific/Pohnpei", Solomon },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
@@ -1512,9 +1663,11 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Africa/Mogadishu", Africa_Eastern },
             { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Ensenada", America_Pacific },
             { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
@@ -1525,9 +1678,11 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
+            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
+            { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1539,6 +1694,7 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
@@ -1549,6 +1705,7 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
             { "Pacific/Johnston", Hawaii_Aleutian },
@@ -1576,6 +1733,7 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Antarctica/Vostok", Vostok },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Chile/Continental", Chile },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
             { "Europe/Luxembourg", Europe_Central },
@@ -1589,6 +1747,7 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Pacific/Pago_Pago", Samoa },
             { "Pacific/Rarotonga", Cook },
             { "Pacific/Tongatapu", Tonga },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "Africa/Ouagadougou", GMT },
@@ -1606,14 +1765,28 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "America/St_Vincent", Atlantic },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
             { "Australia/Adelaide", Australia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
-            { "Europe/Isle_of_Man", GMT },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "Greenwicha \u00e1igi",
+                    "GMT",
+                    "Brihtala\u0161 geasse\u00e1igi",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "Pacific/Kiritimati", Line_Islands },
             { "Africa/Johannesburg", Africa_Southern },
@@ -1631,6 +1804,8 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Pacific/Guadalcanal", Solomon },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
@@ -1641,10 +1816,11 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Santa_Isabel", Mexico_Northwest },
-            { "America/Scoresbysund", Greenland_Eastern },
+            { "America/Santa_Isabel", America_Pacific },
             { "Antarctica/Macquarie", Australia_Eastern },
-            { "Pacific/Port_Moresby", Papua_New_Guinea },
+            { "Australia/Queensland", Australia_Eastern },
+            { "Australia/Yancowinna", Australia_Central },
+            { "Pacific/Port_Moresby", DumontDUrville },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1659,9 +1835,12 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
             { "Atlantic/South_Georgia", South_Georgia },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -1671,12 +1850,15 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "America/Argentina/San_Juan", Argentina },
             { "America/Argentina/San_Luis", Argentina },
             { "America/Indiana/Petersburg", America_Eastern },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Asia/Tehran", "Teheran" },
             { "timezone.excity.Etc/Unknown", "Dovdameahttun g\u00e1vpot" },
             { "timezone.excity.Europe/Rome", "Roma" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Africa/Cairo", "Kairo" },
             { "timezone.excity.Asia/Irkutsk", "Irkuck" },
             { "timezone.excity.Asia/Rangoon", "Rangoon" },
@@ -1693,6 +1875,7 @@ public class TimeZoneNames_se_FI extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Vienna", "Wien" },
             { "timezone.excity.Europe/Warsaw", "Warsawa" },
             { "timezone.excity.Europe/Zurich", "Z\u00fcrich" },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Asia/Kamchatka", "Kam\u010datka" },
