@@ -204,11 +204,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             };
         final String[] India = new String[] {
                "Saa za Wastani za India",
+               "IST",
                "",
+               "IST",
                "",
-               "",
-               "",
-               "",
+               "IST",
             };
         final String[] Japan = new String[] {
                "Saa za Wastani za Japani",
@@ -284,11 +284,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             };
         final String[] Alaska = new String[] {
                "Saa za Wastani za Alaska",
-               "",
+               "AKST",
                "Saa za Mchana za Alaska",
-               "",
+               "AKDT",
                "Saa za Alaska",
-               "",
+               "AKT",
             };
         final String[] Amazon = new String[] {
                "Saa za Wastani za Amazon",
@@ -308,11 +308,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             };
         final String[] Azores = new String[] {
                "Saa za Wastani za Azores",
-               "HMT",
+               "",
                "Saa za Majira ya joto za Azores",
-               "HMT",
+               "",
                "Saa za Azores",
-               "HMT",
+               "",
             };
         final String[] Bhutan = new String[] {
                "Saa za Bhutan",
@@ -598,9 +598,9 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "Saa za Wastani za Atlantiki",
                "AST",
                "Saa za Mchana za Atlantiki",
-               "ADT",
+               "AST",
                "Saa za Atlantiki",
-               "AT",
+               "AST",
             };
         final String[] Brasilia = new String[] {
                "Saa za Wastani za Brasilia",
@@ -972,11 +972,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             };
         final String[] Africa_Central = new String[] {
                "Saa za Afrika ya Kati",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
                "",
-               "SAST",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "Saa za Afrika Mashariki",
@@ -1020,11 +1020,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             };
         final String[] Europe_Western = new String[] {
                "Saa za Wastani za Magharibi mwa Ulaya",
-               "FMT",
+               "WET",
                "Saa za Majira ya joto za Magharibi mwa Ulaya",
-               "FMT",
+               "WEST",
                "Saa za Magharibi mwa Ulaya",
-               "FMT",
+               "WET",
             };
         final String[] Mexico_Pacific = new String[] {
                "Saa za wastani za pasifiki za Meksiko",
@@ -1110,9 +1110,9 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "Saa za Wastani za Mountain",
                "MST",
                "Saa za Mchana za Mountain",
-               "MDT",
+               "MST",
                "Saa za Mountain",
-               "MT",
+               "MST",
             };
         final String[] Marshall_Islands = new String[] {
                "Saa za Visiwa vya Marshall",
@@ -1122,14 +1122,6 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Saa za Wastani za Meksiko Kaskazini Magharibi",
-               "",
-               "Saa za mchana za Meksiko Kaskazini Magharibi",
-               "",
-               "Saa za Meksiko Kaskazini Magharibi",
-               "",
-            };
         final String[] Papua_New_Guinea = new String[] {
                "Saa za Papua New Guinea",
                "",
@@ -1156,27 +1148,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             };
         final String[] Australia_Western = new String[] {
                "Saa za Wastani za Australia Magharibi",
-               "",
+               "AWST",
                "Saa za Mchana za Australia Magharibi",
-               "",
+               "AWDT",
                "Saa za Australia Magharibi",
-               "",
-            };
-        final String[] Greenland_Eastern = new String[] {
-               "Saa za Wastani za Greenland Mashariki",
-               "",
-               "Saa za Majira ya joto za Greenland Mashariki",
-               "",
-               "Saa za Greenland Mashariki",
-               "",
-            };
-        final String[] Greenland_Western = new String[] {
-               "Saa za Wastani za Greenland Magharibi",
-               "",
-               "Saa za Majira ya joto za Greenland Magharibi",
-               "",
-               "Saa za Greenland Magharibi",
-               "",
+               "AWT",
             };
         final String[] Indonesia_Central = new String[] {
                "Saa za Indonesia ya Kati",
@@ -1202,14 +1178,6 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                "",
                "WIB",
             };
-        final String[] Kazakhstan_Eastern = new String[] {
-               "Saa za Kazakhstan Mashariki",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Kazakhstan_Western = new String[] {
                "Saa za Kazakhstan Magharibi",
                "",
@@ -1245,8 +1213,20 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
             { "UTC", ETC_UTC },
+            { "GB",
+                new String[] {
+                    "Saa za Greenwich",
+                    "GMT",
+                    "Saa za Majira ya Joto za Uingereza",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "NZ", New_Zealand },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "BET", Brasilia },
@@ -1257,21 +1237,103 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "CTT", China },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "IET", America_Eastern },
+            { "IST", India },
             { "JST", Japan },
             { "MIT", Apia },
             { "NET", Armenia },
             { "NST", New_Zealand },
             { "PLT", Pakistan },
             { "PNT", America_Mountain },
+            { "PRC", China },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "ROK", Korea },
             { "SST", Solomon },
+            { "UCT",
+                new String[] {
+                    "Mfumo wa kuratibu saa ulimwenguni",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "VST", Indochina },
+            { "Cuba", Cuba },
+            { "Eire",
+                new String[] {
+                    "Saa za Greenwich",
+                    "GMT",
+                    "Saa za Majira ya Joto za Ayalandi",
+                    "IST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "GMT0", GMT },
+            { "Iran", Iran },
+            { "W-SU", Moscow },
+            { "Zulu",
+                new String[] {
+                    "Mfumo wa kuratibu saa ulimwenguni",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Japan", Japan },
+            { "Libya", Europe_Eastern },
+            { "Israel", Israel },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "Mfumo wa kuratibu saa ulimwenguni",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Etc/UTC", ETC_UTC },
+            { "GB-Eire",
+                new String[] {
+                    "Saa za Greenwich",
+                    "GMT",
+                    "Saa za Majira ya Joto za Uingereza",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
+            { "NZ-CHAT", Chatham },
             { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "Mfumo wa kuratibu saa ulimwenguni",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Hongkong", Hong_Kong },
+            { "Portugal", Europe_Western },
+            { "US/Samoa", Samoa },
             { "Asia/Aden", Arabian },
             { "Asia/Baku", Azerbaijan },
             { "Asia/Dili", East_Timor },
@@ -1279,17 +1341,40 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Kwajalein", Marshall_Islands },
+            { "Singapore", Singapore },
+            { "US/Alaska", Alaska },
+            { "US/Hawaii", Hawaii_Aleutian },
+            { "Universal",
+                new String[] {
+                    "Mfumo wa kuratibu saa ulimwenguni",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Dubai", Gulf },
             { "Asia/Kabul", Afghanistan },
+            { "Asia/Macao", China },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
-            { "Asia/Almaty", Kazakhstan_Eastern },
+            { "Asia/Almaty", Kazakhstan_Western },
             { "Asia/Anadyr", Anadyr },
             { "Asia/Aqtobe", Kazakhstan_Western },
             { "Asia/Atyrau", Kazakhstan_Western },
@@ -1304,12 +1389,20 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Asia/Saigon", Indochina },
             { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
+            { "Asia/Thimbu", Bhutan },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/East", Brasilia },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Indian/Mahe", Seychelles },
-            { "Pacific/Yap", Truk },
+            { "Pacific/Yap", Papua_New_Guinea },
+            { "US/Aleutian", Hawaii_Aleutian },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Accra", GMT },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
@@ -1317,6 +1410,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
             { "America/Adak", Hawaii_Aleutian },
+            { "America/Atka", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
             { "Asia/Baghdad", Arabian },
@@ -1327,7 +1421,8 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Asia/Irkutsk", Irkutsk },
             { "Asia/Jakarta", Indonesia_Western },
             { "Asia/Karachi", Pakistan },
-            { "Asia/Kuching", Malaysia },
+            { "Asia/Kolkata", India },
+            { "Asia/Kuching", Brunei },
             { "Asia/Magadan", Magadan },
             { "Asia/Nicosia", Europe_Eastern },
             { "Asia/Rangoon", Myanmar },
@@ -1335,6 +1430,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Asia/Thimphu", Bhutan },
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
+            { "Canada/Yukon", Yukon },
             { "Europe/Malta", Europe_Central },
             { "Europe/Minsk", Moscow },
             { "Europe/Sofia", Europe_Eastern },
@@ -1352,6 +1448,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "SystemV/MST7", America_Mountain },
             { "SystemV/PST8", Pitcairn },
             { "SystemV/YST9", Gambier },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bamako", GMT },
             { "Africa/Bangui", Africa_Western },
@@ -1379,10 +1476,25 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Western },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
+            { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/LHI", Lord_Howe },
+            { "Australia/NSW", Australia_Eastern },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "Mfumo wa kuratibu saa ulimwenguni",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
@@ -1395,7 +1507,16 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
-            { "Europe/Jersey", GMT },
+            { "Europe/Jersey",
+                new String[] {
+                    "Saa za Greenwich",
+                    "GMT",
+                    "Saa za Majira ya Joto za Uingereza",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -1420,9 +1541,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Indian/Chagos", Indian_Ocean },
             { "Indian/Comoro", Africa_Eastern },
+            { "Pacific/Chuuk", Papua_New_Guinea },
             { "Pacific/Efate", Vanuatu },
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
+            { "Pacific/Samoa", Samoa },
             { "SystemV/HST10", Hawaii_Aleutian },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
@@ -1449,15 +1572,24 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
+            { "Asia/Chungking", China },
             { "Asia/Hong_Kong", Hong_Kong },
             { "Asia/Kamchatka", Kamchatka },
+            { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
             { "Asia/Pyongyang", Korea },
             { "Asia/Qyzylorda", Kazakhstan_Western },
             { "Asia/Samarkand", Uzbekistan },
             { "Asia/Singapore", Singapore },
             { "Asia/Vientiane", Indochina },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -1469,21 +1601,25 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "Indian/Reunion", Reunion },
+            { "Mexico/BajaSur", Mexico_Pacific },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kanton", Phoenix_Islands },
             { "Pacific/Kosrae", Kosrae },
             { "Pacific/Majuro", Marshall_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
-            { "Pacific/Ponape", Ponape },
+            { "Pacific/Ponape", Solomon },
             { "Pacific/Saipan", Chamorro },
             { "Pacific/Tahiti", Tahiti },
-            { "Pacific/Tarawa", Gilbert_Islands },
-            { "Pacific/Wallis", Wallis },
+            { "Pacific/Tarawa", Marshall_Islands },
+            { "Pacific/Wallis", Gilbert_Islands },
             { "Africa/Blantyre", Africa_Central },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Freetown", GMT },
@@ -1502,10 +1638,10 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Godthab", Greenland_Western },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
@@ -1519,25 +1655,41 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "America/Yakutat", Alaska },
             { "Asia/Choibalsan", Mongolia },
             { "Asia/Phnom_Penh", Indochina },
+            { "Asia/Ulan_Bator", Mongolia },
             { "Atlantic/Azores", Azores },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/North", Australia_Central },
             { "Australia/Perth", Australia_Western },
+            { "Australia/South", Australia_Central },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
-            { "Europe/Guernsey", GMT },
+            { "Europe/Guernsey",
+                new String[] {
+                    "Saa za Greenwich",
+                    "GMT",
+                    "Saa za Majira ya Joto za Uingereza",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
-            { "Indian/Maldives", Maldives },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
             { "Pacific/Fakaofo", Tokelau },
             { "Pacific/Gambier", Gambier },
             { "Pacific/Norfolk", Norfolk },
+            { "Pacific/Pohnpei", Solomon },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
@@ -1548,9 +1700,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Africa/Mogadishu", Africa_Eastern },
             { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Ensenada", America_Pacific },
             { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
@@ -1561,9 +1715,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
+            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
+            { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1575,6 +1731,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
@@ -1585,6 +1742,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
             { "Pacific/Johnston", Hawaii_Aleutian },
@@ -1612,6 +1770,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Antarctica/Vostok", Vostok },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Chile/Continental", Chile },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
             { "Europe/Luxembourg", Europe_Central },
@@ -1625,6 +1784,7 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Pacific/Pago_Pago", Samoa },
             { "Pacific/Rarotonga", Cook },
             { "Pacific/Tongatapu", Tonga },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "Africa/Ouagadougou", GMT },
@@ -1643,14 +1803,28 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
             { "Australia/Adelaide", Australia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
-            { "Europe/Isle_of_Man", GMT },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "Saa za Greenwich",
+                    "GMT",
+                    "Saa za Majira ya Joto za Uingereza",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "Pacific/Kiritimati", Line_Islands },
             { "Africa/Johannesburg", Africa_Southern },
@@ -1668,6 +1842,8 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Pacific/Guadalcanal", Solomon },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
@@ -1678,10 +1854,11 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Santa_Isabel", Mexico_Northwest },
-            { "America/Scoresbysund", Greenland_Eastern },
+            { "America/Santa_Isabel", America_Pacific },
             { "Antarctica/Macquarie", Australia_Eastern },
-            { "Pacific/Port_Moresby", Papua_New_Guinea },
+            { "Australia/Queensland", Australia_Eastern },
+            { "Australia/Yancowinna", Australia_Central },
+            { "Pacific/Port_Moresby", DumontDUrville },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1696,9 +1873,12 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
             { "Atlantic/South_Georgia", South_Georgia },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -1709,22 +1889,24 @@ public class TimeZoneNames_sw extends TimeZoneNamesBundle {
             { "America/Argentina/San_Luis", Argentina },
             { "America/Indiana/Petersburg", America_Eastern },
             { "timezone.excity.Asia/Macau", "Macau" },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Etc/Unknown", "Jiji Lisilojulikana" },
             { "timezone.excity.Europe/Kiev", "Kiev" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Asia/Rangoon", "Rangoon" },
             { "timezone.excity.Asia/Qostanay", "Kostanay" },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.America/Cancun", "Cancun" },
             { "timezone.excity.America/Merida", "Merida" },
-            { "timezone.excity.Australia/Currie", "Currie" },
             { "timezone.excity.Pacific/Honolulu", "Honolulu" },
             { "timezone.excity.Pacific/Enderbury", "Enderbury" },
             { "timezone.excity.America/Mexico_City", "Jiji la Mexico" },
-            { "timezone.excity.America/Santa_Isabel", "Santa Isabel" },
             { "timezone.excity.America/Ciudad_Juarez", "Ciudad Juarez" },
             { "timezone.excity.America/Bahia_Banderas", "Bahia Banderas" },
             { "timezone.excity.Atlantic/South_Georgia", "Georgia Kusini" },
